flats = "EASE2_S36km.lats.500x500x1.double" 
flons = "EASE2_S36km.lons.500x500x1.double" 

nlat = 500
nlon = 500

setfileoption ("bin", "ReadByteOrder", "LittleEndian")

glat  = fbindirread (flats, 0, -1, "double")
glon  = fbindirread (flons, 0, -1, "double")

lon = glon(0:nlon-1)
lat = glat(0::nlon)

lon!0         = "lon" 
lon@long_name = "lon" 
lon@units     = "degrees_east" 
lon&lon       = lon

lat!0         = "lat" 
lat@long_name = "lat" 
lat@units     = "degrees_north" 
lat&lat       = lat
lat = lat(::-1)

;-- dummy time and data
time   = cd_inv_calendar(2020,6,30,12,0,0,"hours since 2020-01-01 00:00:00",0)
time!0 = "time" 
time@long_name = "time" 

data = new((/1,nlat,nlon/), "float")
data!0 = "time" 
data!1 = "lat" 
data!2 = "lon" 
data&time = time
data&lat  = lat
data&lon  = lon

;-- write grid and dummy data to netCDF file
setfileoption("nc","Format","NetCDF4Classic")
system("rm -rf EASE2_S36km.lats.500x500_grid.nc")
fout = addfile("EASE2_S36km.lats.500x500_grid.nc","c")

setfileoption(fout, "DefineMode", True)

fAtt               =  True        ;-- assign file attributes
fAtt@title         = "Convert binary to netCDF"  
fAtt@source_file   = "EASE2_S36km.lats.500x500x1.double; EASE2_S36km.lons.500x500x1.double" 
fAtt@creation_date =  systemfunc ("date")          
fileattdef(fout,fAtt) 

dimNames = (/"time", "lat", "lon"/)  
dimSizes = (/ -1   ,  nlat,  nlon /) 
dimUnlim = (/ True , False, False/)   
filedimdef(fout,dimNames,dimSizes,dimUnlim)

filevardef(fout, "time", typeof(time), getvardims(time)) 
filevardef(fout, "lat" , typeof(lat),  getvardims(lat))                         
filevardef(fout, "lon" , typeof(lon),  getvardims(lon))                         
filevardef(fout, "data", typeof(data), getvardims(data))

filevarattdef(fout, "time", time)
filevarattdef(fout, "lat" , lat)
filevarattdef(fout, "lon" , lon)
filevarattdef(fout, "data", data)

setfileoption(fout,"DefineMode",False)

fout->lat  = (/lat/)
fout->lon  = (/lon/)
fout->data = (/data/)
fout->time = (/time/)